Learn R Programming

mlrintermbo (version 0.5.1)

captureSpecials: Capture Warnings and Errors

Description

Converts warnings and errors into in-band information. This function is for internal use and is used within the attached R session in the background.

Usage

captureSpecials(expr)

Arguments

expr

expression to evaluate.